@@ -1,4 +1,4 @@
-__version__ = "0.2.3"
+__version__ = "0.3.0"
 import sys
 import logging
 from . import util
@@ -24,6 +24,7 @@ log_handler.setFormatter(logging.Formatter('[%(name)s] [%(levelname)s] %(message
 logger.addHandler(log_handler)
 
 # providers
+accuracy = providers.registry['accuracy']
 cwl_eval = providers.registry['cwl_eval']
 compat = providers.registry['compat']
 gdeval = providers.registry['gdeval']
@@ -32,6 +33,11 @@ trectools = providers.registry['trectools']
 judged = providers.registry['judged']
 msmarco = providers.registry['msmarco']
 pyndeval = providers.registry['pyndeval']
+ranx = providers.registry['ranx']
+runtime = providers.registry['runtime']
+
+define = providers.define
+define_byquery = providers.define_byquery
 
 CwlMetric = providers.CwlMetric
 
@@ -44,6 +50,9 @@ DefaultPipeline = providers.FallbackProvider([
     judged,
     msmarco,
     gdeval,  # doesn't work when installed from package #9
+    accuracy,
+    ranx,
+    runtime,
 ])
 evaluator = DefaultPipeline.evaluator
 calc_ctxt = DefaultPipeline.calc_ctxt # deprecated; replaced with evaluator
