@@ -18,6 +18,8 @@ class _Bpref(measures.Measure):
     """
     __name__ = 'Bpref'
     NAME = __name__
+    PRETTY_NAME = 'Binary Preference'
+    SHORT_DESC = 'The relative ranks of judged relevant and non-relevant documents.'
     SUPPORTED_PARAMS = {
         'rel': measures.ParamInfo(dtype=int, default=1, desc='minimum relevance score to be considered relevant (inclusive)')
     }
