@@ -5,8 +5,8 @@ import ast
 import contextlib
 import itertools
 import tempfile
-from typing import List
-from collections import namedtuple
+from typing import Dict, List
+from collections import namedtuple, defaultdict
 from typing import NamedTuple, Union
 import ir_measures
 
@@ -227,6 +227,15 @@ class RunConverter:
         if qid is not None:
             yield from flush()
 
+    def as_sorteddict(self) -> Dict[str, List[ScoredDoc]]:
+        """Returns a map of topic ID -> sorted list of documents"""
+        pertopic = defaultdict(list)
+        for item in self.as_namedtuple_iter():
+            pertopic[item.query_id].append(item)
+        pertopic = {qid: sorted(items, key=lambda x: x.score, reverse=True) for qid, items in pertopic.items()}
+
+        return pertopic
+
     def as_pd_dataframe(self):
         t, err = self.predict_type()
         if t == 'pd_dataframe':
@@ -304,6 +313,8 @@ def _ast_to_value(node):
         return node.s
     if isinstance(node, ast.NameConstant):
         return node.value
+    if isinstance(node, ast.Dict):
+        return dict(zip(map(_ast_to_value, node.keys), map(_ast_to_value, node.values)))
     raise ValueError(_AST_PARSE_ERROR.format('values must be str, float, int, bool, etc.'))
 
 
